<?php
/*
Plugin Name: Komoona
Plugin URI: http://www.komoona.com/support/wordpress-plugin
Description: Easily integrate the Komoona Tool to WordPress.
Version: 1.1.02.1
Author: The Komoona Team
Author URI: http://www.komoona.com
*/

/*
Copyright 2011 Komoona (email : Support@Komoona.com)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// handle post data - store POST data to the data store
if($_POST['komoona_hidden'] == 'Y') {

	// komoona enable\disable
	$enable_komoona = false;
	if ($_POST['enable_disable_komoona'] === 'enable_disable_komoona') {
		$enable_komoona = true;
	}
	update_option('enable_disable_komoona', $enable_komoona);

	// widget ad unit snippet
	$widget_code = $_POST['komoona_widget_layout_id'];
	update_option('komoona_widget_layout_id', $widget_code);

	// script code
	$script_code = $_POST['komoona_script_url'];
	update_option('komoona_script_url', $script_code);

}

// add Komoona script only if we're not in the Dashboard or the administration panels
if( ! is_admin() ) {
	add_action('wp_print_scripts', 'komoona_enqueue_script');
}

// add Komoona widget to the side bar
add_action('widgets_init', create_function('', 'return register_widget("Komoona_Widget");'));

// create plugin configuration menu
add_action('admin_menu', 'komoona_plugin_init');

$plugin = plugin_basename(__FILE__);

// add a “Settings” link directly on the plugins page
add_filter("plugin_action_links_$plugin", 'komoona_settings_link' );

// 'install' section: register default options
register_activation_hook( __FILE__, 'komoona_activate');

// 'un-install' section: remove plugin options from the data store
register_deactivation_hook( __FILE__, 'komoona_deactivate');

/**
 * Register Komoona plugin default options to the data store. This function is called when the
 * plug in is activate
 */
function komoona_activate() {
	// add default options to the data store
	add_option('enable_disable_komoona', true);
	add_option('komoona_widget_layout_name', 'Komoona');
	add_option('komoona_widget_layout_id', '');
	add_option('komoona_script_url' , '');
}

/**
 * Remove Komoona plugin options from the data store. This function is called when the
 * plug in is deactivate
 */
function komoona_deactivate() {
	 // remove plugin optioins from the data store
	 delete_option('enable_disable_komoona');
	 delete_option('komoona_widget_layout_name');
	 delete_option('komoona_widget_layout_id');
	 delete_option('komoona_script_url');
}

/**
 * Add settings link on plugin page
 */
function komoona_settings_link($links) {
	 $settings_link = '<a href="options-general.php?page=komoona_options">Settings</a>';
	 array_unshift($links, $settings_link);
	 return $links;
}

/**
 * Enqueue the komoona script to the page footer if komoona is enabled
 */
function komoona_enqueue_script() {

	// verify komoona is enabled
	$komoona_enabled = get_option('enable_disable_komoona');

	if ($komoona_enabled) {
		  // a safe way of adding javascripts to a WordPress generated page. Komoona script
		  // is placed at the bottom of the <body>
		  wp_enqueue_script('komoonascript', get_option('komoona_script_url'), false, false, true);
	}
}

/**
 * Init the Komoona plugin settings page
 */
function komoona_plugin_init() {

	//call register settings function
	add_action( 'admin_init', 'register_komoona_settings' );

	add_options_page('Komoona Options', 'Komoona', 'manage_options', 'komoona_options', 'komoona_plugin_options');
}

function register_komoona_settings() {
	//register our settings
	register_setting( 'komoona-settings-group', 'enable_disable_komoona' );
	register_setting( 'komoona-settings-group', 'komoona_widget_layout_id' );
	register_setting( 'komoona-settings-group', 'komoona_script_url' );
}

/**
 * Create the Komoona options page
 */
function komoona_plugin_options() {
	if (!current_user_can('manage_options'))  {
		wp_die( __('You do not have sufficient permissions to access this page.') );
	}
	?>
	<div class="wrap">
		<h2>Komoona Options</h2>
		<?php $script_url = get_option('komoona_script_url'); ?>
		<?php if(strlen($script_url) == 0) : ?>
		<div style="text-align: left;font-weight:normal;color:black;padding: 5px 5px; margin-bottom: 10px; border: 1px solid #A31919; background-color: #ffd;">
			   <p style="font-size: 16px;">Please <a href="https://www.komoona.com/users/registration/platform/wordpress" target="_blank">click </a> to create your Komoona account and activate the plugin.</p>
			   <p style="font-size: 12px;">You must create account on Kommona to get your own widget code and Script.</p>
		</div>
		<?php endif; ?>
		<form method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
		<?php settings_fields( 'komoona-settings-group' ); ?>

		<table class="form-table">

			<tr valign="top">
				<th scope="row">Enable\Disable Komoona Code</th>
				<td><input type="checkbox" name="enable_disable_komoona" value="enable_disable_komoona" <?php echo (get_option('enable_disable_komoona') ? 'checked="checked"' : '') ?>" /></td>
			</tr>

			<tr valign="top">
				<th scope="row">Komoona Widget Code</th>
				<td>
					<input type="text" style="width:600px;" name="komoona_widget_layout_id" value="<?php echo get_option('komoona_widget_layout_id'); ?>" />
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">Komoona Script URL</th>
				<td>
					<input type="text" style="width:600px;" name="komoona_script_url" value="<?php echo get_option('komoona_script_url'); ?>" />
				</td>
			</tr>

		</table>

		<input type="hidden" name="komoona_hidden" value="Y">

		<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		</p>

		</form>
	</div>
<?php } // end of komoona_plugin_options

/**
 * Komoona Widget Class
 */
class Komoona_Widget extends WP_Widget {

    /** constructor */
    function Komoona_Widget() {
        /* Widget settings. */
		$widget_ops = array( 'classname' => 'Komoona', 'description' => 'Show Komoona Ads Unit in your sidebar' );

		/* Widget control settings. */
		$control_ops = array( 'width' => 200, 'height' => 100, 'id_base' => 'komoona-widget' );

		$komoona_name = 'Komoona';

		$layout_name = get_option('komoona_widget_layout_name');
		if (strlen($layout_name)) {
			 $komoona_name .= '[' . $layout_name . ']';
		}

		parent::WP_Widget('komoona-widget', $name = $komoona_name, $widget_ops, $control_ops);
    }

	// outputs the content of the widget
    function widget($args, $instance) {
        extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
		  echo $before_title . $title . $after_title;

		// Ad unit (verify that Komoona is enabled)
		$komoona_enabled = get_option('enable_disable_komoona');
		if ($komoona_enabled) {
			$widget_code = get_option('komoona_widget_layout_id');
			echo '<div id="' . $widget_code . '"></div>';
		}

		/* After widget (defined by themes). */
		echo $after_widget;
    }

	// processes widget options to be saved
    function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
			return $instance;
    }

	// outputs the options form on admin
    function form($instance) {
         $title = esc_attr($instance['title']);
        ?>
         <p>
          <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
          <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
        </p>
        <?php
    }

} // class KomoonaWidget

//end of file ?>